==> box64_0.2.6+dfsg.orig.tar.xz: box64-0.2.6/src/wrapped/wrappedlibxcbsync_private.h <==
#if !(defined(GO) && defined(GOM) && defined(GO2) && defined(DATA))
#error meh!
#endif

//GO(xcb_sync_alarm_end, 
//GO(xcb_sync_alarm_next, 
//GO(xcb_sync_await, 
//GO(xcb_sync_await_checked, 
//GO(xcb_sync_await_fence, 
//GO(xcb_sync_await_fence_checked, 
//GO(xcb_sync_await_fence_fence_list, 
//GO(xcb_sync_await_fence_fence_list_end, 
//GO(xcb_sync_await_fence_fence_list_length, 
//GO(xcb_sync_await_fence_sizeof, 
//GO(xcb_sync_await_sizeof, 
//GO(xcb_sync_await_wait_list, 
//GO(xcb_sync_await_wait_list_iterator, 
//GO(xcb_sync_await_wait_list_length, 
//GO(xcb_sync_change_alarm, 
//GO(xcb_sync_change_alarm_aux, 
//GO(xcb_sync_change_alarm_aux_checked, 
//GO(xcb_sync_change_alarm_checked, 
//GO(xcb_sync_change_alarm_sizeof, 
//GO(xcb_sync_change_alarm_value_list, 
//GO(xcb_sync_change_alarm_value_list_serialize, 
//GO(xcb_sync_change_alarm_value_list_sizeof, 
//GO(xcb_sync_change_alarm_value_list_unpack, 
//GO(xcb_sync_change_counter, 
//GO(xcb_sync_change_counter_checked, 
//GO(xcb_sync_counter_end, 
//GO(xcb_sync_counter_next, 
//GO(xcb_sync_create_alarm, 
//GO(xcb_sync_create_alarm_aux, 
//GO(xcb_sync_create_alarm_aux_checked, 
//GO(xcb_sync_create_alarm_checked, 
//GO(xcb_sync_create_alarm_sizeof, 
//GO(xcb_sync_create_alarm_value_list, 
//GO(xcb_sync_create_alarm_value_list_serialize, 
//GO(xcb_sync_create_alarm_value_list_sizeof, 
//GO(xcb_sync_create_alarm_value_list_unpack, 
GO(xcb_sync_create_counter, pFpppU)
GO(xcb_sync_create_counter_checked, pFpppU)
//GO(xcb_sync_create_fence, 
//GO(xcb_sync_create_fence_checked, 
//GO(xcb_sync_destroy_alarm, 
//GO(xcb_sync_destroy_alarm_checked, 
GO(xcb_sync_destroy_counter, pFppp)
GO(xcb_sync_destroy_counter_checked, pFppp)
//GO(xcb_sync_destroy_fence, 
//GO(xcb_sync_destroy_fence_checked, 
//GO(xcb_sync_fence_end, 
//GO(xcb_sync_fence_next, 
//GO(xcb_sync_get_priority, 
//GO(xcb_sync_get_priority_reply, 
//GO(xcb_sync_get_priority_unchecked, 
DATA(xcb_sync_id, 2*sizeof(void*))
//GO(xcb_sync_initialize, 
//GO(xcb_sync_initialize_reply, 
//GO(xcb_sync_initialize_unchecked, 
//GO(xcb_sync_int64_end, 
//GO(xcb_sync_int64_next, 
//GO(xcb_sync_list_system_counters, 
//GO(xcb_sync_list_system_counters_counters_iterator, 
//GO(xcb_sync_list_system_counters_counters_length, 
//GO(xcb_sync_list_system_counters_reply, 
//GO(xcb_sync_list_system_counters_sizeof, 
//GO(xcb_sync_list_system_counters_unchecked, 
//GO(xcb_sync_query_alarm, 
//GO(xcb_sync_query_alarm_reply, 
//GO(xcb_sync_query_alarm_unchecked, 
//GO(xcb_sync_query_counter, 
//GO(xcb_sync_query_counter_reply, 
//GO(xcb_sync_query_counter_unchecked, 
//GO(xcb_sync_query_fence, 
//GO(xcb_sync_query_fence_reply, 
//GO(xcb_sync_query_fence_unchecked, 
//GO(xcb_sync_reset_fence, 
//GO(xcb_sync_reset_fence_checked, 
GO(xcb_sync_set_counter, pFpppU)
GO(xcb_sync_set_counter_checked, pFpppU)
//GO(xcb_sync_set_priority, 
//GO(xcb_sync_set_priority_checked, 
//GO(xcb_sync_systemcounter_end, 
//GO(xcb_sync_systemcounter_name, 
//GO(xcb_sync_systemcounter_name_end, 
//GO(xcb_sync_systemcounter_name_length, 
//GO(xcb_sync_systemcounter_next, 
//GO(xcb_sync_systemcounter_sizeof, 
//GO(xcb_sync_trigger_end, 
//GO(xcb_sync_trigger_fence, 
//GO(xcb_sync_trigger_fence_checked, 
//GO(xcb_sync_trigger_next, 
//GO(xcb_sync_waitcondition_end, 
//GO(xcb_sync_waitcondition_next,

==> box64_0.3.0+dfsg.orig.tar.xz: box64-0.3.0/src/wrapped/wrappedlibxcbsync_private.h <==
#if !(defined(GO) && defined(GOM) && defined(GO2) && defined(DATA))
#error meh!
#endif

//GO(xcb_sync_alarm_end, 
//GO(xcb_sync_alarm_next, 
//GO(xcb_sync_await, 
//GO(xcb_sync_await_checked, 
//GO(xcb_sync_await_fence, 
//GO(xcb_sync_await_fence_checked, 
//GO(xcb_sync_await_fence_fence_list, 
//GO(xcb_sync_await_fence_fence_list_end, 
//GO(xcb_sync_await_fence_fence_list_length, 
//GO(xcb_sync_await_fence_sizeof, 
//GO(xcb_sync_await_sizeof, 
//GO(xcb_sync_await_wait_list, 
//GO(xcb_sync_await_wait_list_iterator, 
//GO(xcb_sync_await_wait_list_length, 
//GO(xcb_sync_change_alarm, 
//GO(xcb_sync_change_alarm_aux, 
//GO(xcb_sync_change_alarm_aux_checked, 
//GO(xcb_sync_change_alarm_checked, 
//GO(xcb_sync_change_alarm_sizeof, 
//GO(xcb_sync_change_alarm_value_list, 
//GO(xcb_sync_change_alarm_value_list_serialize, 
//GO(xcb_sync_change_alarm_value_list_sizeof, 
//GO(xcb_sync_change_alarm_value_list_unpack, 
//GO(xcb_sync_change_counter, 
//GO(xcb_sync_change_counter_checked, 
//GO(xcb_sync_counter_end, 
//GO(xcb_sync_counter_next, 
//GO(xcb_sync_create_alarm, 
//GO(xcb_sync_create_alarm_aux, 
//GO(xcb_sync_create_alarm_aux_checked, 
//GO(xcb_sync_create_alarm_checked, 
//GO(xcb_sync_create_alarm_sizeof, 
//GO(xcb_sync_create_alarm_value_list, 
//GO(xcb_sync_create_alarm_value_list_serialize, 
//GO(xcb_sync_create_alarm_value_list_sizeof, 
//GO(xcb_sync_create_alarm_value_list_unpack, 
GO(xcb_sync_create_counter, uFbuU)
GO(xcb_sync_create_counter_checked, uFbuU)
//GO(xcb_sync_create_fence, 
//GO(xcb_sync_create_fence_checked, 
//GO(xcb_sync_destroy_alarm, 
//GO(xcb_sync_destroy_alarm_checked, 
GO(xcb_sync_destroy_counter, pFbpp)
GO(xcb_sync_destroy_counter_checked, pFbpp)
//GO(xcb_sync_destroy_fence, 
//GO(xcb_sync_destroy_fence_checked, 
//GO(xcb_sync_fence_end, 
//GO(xcb_sync_fence_next, 
//GO(xcb_sync_get_priority, 
//GO(xcb_sync_get_priority_reply, 
//GO(xcb_sync_get_priority_unchecked, 
DATA(xcb_sync_id, 2*sizeof(void*))
//GO(xcb_sync_initialize, 
//GO(xcb_sync_initialize_reply, 
//GO(xcb_sync_initialize_unchecked, 
//GO(xcb_sync_int64_end, 
//GO(xcb_sync_int64_next, 
//GO(xcb_sync_list_system_counters, 
//GO(xcb_sync_list_system_counters_counters_iterator, 
//GO(xcb_sync_list_system_counters_counters_length, 
//GO(xcb_sync_list_system_counters_reply, 
//GO(xcb_sync_list_system_counters_sizeof, 
//GO(xcb_sync_list_system_counters_unchecked, 
//GO(xcb_sync_query_alarm, 
//GO(xcb_sync_query_alarm_reply, 
//GO(xcb_sync_query_alarm_unchecked, 
//GO(xcb_sync_query_counter, 
//GO(xcb_sync_query_counter_reply, 
//GO(xcb_sync_query_counter_unchecked, 
//GO(xcb_sync_query_fence, 
//GO(xcb_sync_query_fence_reply, 
//GO(xcb_sync_query_fence_unchecked, 
//GO(xcb_sync_reset_fence, 
//GO(xcb_sync_reset_fence_checked, 
GO(xcb_sync_set_counter, pFbppU)
GO(xcb_sync_set_counter_checked, pFbppU)
//GO(xcb_sync_set_priority, 
//GO(xcb_sync_set_priority_checked, 
//GO(xcb_sync_systemcounter_end, 
//GO(xcb_sync_systemcounter_name, 
//GO(xcb_sync_systemcounter_name_end, 
//GO(xcb_sync_systemcounter_name_length, 
//GO(xcb_sync_systemcounter_next, 
//GO(xcb_sync_systemcounter_sizeof, 
//GO(xcb_sync_trigger_end, 
//GO(xcb_sync_trigger_fence, 
//GO(xcb_sync_trigger_fence_checked, 
//GO(xcb_sync_trigger_next, 
//GO(xcb_sync_waitcondition_end, 
//GO(xcb_sync_waitcondition_next,
